@@ -1,11 +1,9 @@
-mod common;
-
-use crate::common::{ErrorsOnDrop, Mode, Random, TryDropTypes};
 use once_cell::sync::OnceCell;
 use std::sync::Arc;
 use try_drop::drop_strategies::once_cell::Ignore;
-use try_drop::drop_strategies::{OnceCellTryDropStrategy, PanicDropStrategy};
-use try_drop::{DropAdapter, PureTryDrop};
+use try_drop::drop_strategies::{OnceCellDropStrategy, PanicDropStrategy};
+use try_drop::test_utils::{ErrorsOnDrop, Mode, Random, TryDropTypes};
+use try_drop::{adapters::DropAdapter, PureTryDrop};
 
 fn drops_value<M: Mode, TDT: TryDropTypes>(value: DropAdapter<ErrorsOnDrop<M, TDT>>)
 where
@@ -16,7 +14,7 @@ where
 
 fn main() {
     let error = Arc::new(OnceCell::new());
-    let strategy = OnceCellTryDropStrategy::<Ignore>::new(Arc::clone(&error));
+    let strategy = OnceCellDropStrategy::<Ignore>::new(Arc::clone(&error));
     let value = ErrorsOnDrop::<Random, _>::given(strategy, PanicDropStrategy::DEFAULT).adapt();
 
     println!("will only error on drop sometimes");
