@@ -24,6 +24,9 @@ mod adhoc;
 #[cfg(feature = "ds-once-cell")]
 pub mod once_cell;
 
+#[cfg(feature = "ds-unreachable")]
+pub mod unreachable;
+
 #[cfg(feature = "ds-abort")]
 pub use abort::AbortDropStrategy;
 
@@ -40,19 +43,21 @@ pub use noop::NoOpDropStrategy;
 pub use panic::PanicDropStrategy;
 
 #[cfg(feature = "ds-write")]
-pub use write::WriteDropStrategy;
+pub use write::{ThreadUnsafeWriteDropStrategy, WriteDropStrategy};
 
 #[cfg(feature = "ds-adhoc")]
 pub use adhoc::{
-    AdHocFallibleTryDropStrategy, AdHocTryDropStrategy, IntoAdHocFallibleTryDropStrategy,
-    IntoAdHocTryDropStrategy,
+    AdHocDropStrategy, AdHocFallibleDropStrategy, IntoAdHocDropStrategy,
+    IntoAdHocFallibleDropStrategy,
 };
 
 #[cfg(feature = "ds-adhoc-mut")]
 pub use adhoc::{
-    AdHocMutFallibleTryDropStrategy, AdHocMutTryDropStrategy, IntoAdHocMutFallibleTryDropStrategy,
-    IntoAdHocMutTryDropStrategy,
+    AdHocMutDropStrategy, AdHocMutFallibleDropStrategy, IntoAdHocMutDropStrategy,
+    IntoAdHocMutFallibleDropStrategy, IntoThreadUnsafeAdHocMutDropStrategy,
+    IntoThreadUnsafeAdHocMutFallibleDropStrategy, ThreadUnsafeAdHocMutDropStrategy,
+    ThreadUnsafeAdHocMutFallibleDropStrategy,
 };
 
 #[cfg(feature = "ds-once-cell")]
-pub use self::once_cell::OnceCellTryDropStrategy;
+pub use self::once_cell::{OnceCell, OnceCellDropStrategy, ThreadUnsafeOnceCellDropStrategy};
